-   https://github.com/Neargye/magic_enum
-   https://github.com/TartanLlama/optional
-   https://github.com/Tencent/rapidjson/tree/00dbcf2c6e03c47d6c399338b6de060c71356464
-   https://github.com/district10/geojson-cpp/tree/fef5888142373cc07561987b8c8ba4bd64e2380b
-   https://github.com/district10/geometry.hpp/tree/8949904a2b6e0295df2db09b06a643f573e714d0
-   https://github.com/doctest/doctest/tree/4d8716f1efc1d14aa736ef52ee727bd4204f4c40
-   https://github.com/dpilger26/NumCpp
-   https://github.com/felixguendling/cista
-   https://github.com/gabime/spdlog/tree/v1.x/include/spdlog
-   https://github.com/libigl/libigl (no copyleft code)
-   https://github.com/mapbox/cheap-ruler-cpp (modified)
-   https://github.com/mapbox/geojson-vt-cpp
-   https://github.com/mapbox/gzip-hpp
-   https://github.com/mapbox/protozero/tree/85db94025f60fb5d746005f97360094c1fe9c9be
-   https://github.com/mapbox/variant/tree/a2a4858345423a760eca300ec42acad1ad123aa3
-   https://github.com/nlohmann/json/releases/tag/v3.11.2
-   https://github.com/sharkdp/dbg-macro/tree/4db61805d90cb66d91bcc56c2703591a0127ed11
-   https://github.com/taskflow/taskflow
-   https://github.com/yuki-koyama/tinycolormap
-   https://gitlab.com/libeigen/eigen/-/archive/3.4.0/eigen-3.4.0.zip
-   https://raw.githubusercontent.com/Dobiasd/FunctionalPlus/master/include_all_in_one/include/fplus/fplus.hpp
-   https://raw.githubusercontent.com/adamyaxley/Obfuscate/master/obfuscate.h
-   https://raw.githubusercontent.com/jlblancoc/nanoflann/master/include/nanoflann.hpp
-   https://raw.githubusercontent.com/mapbox/eternal/master/include/mapbox/eternal.hpp
-   https://raw.githubusercontent.com/martinus/nanobench/v4.3.7/src/include/nanobench.h
-   https://raw.githubusercontent.com/p-ranav/indicators/master/single_include/indicators/indicators.hpp
